# Policy on usage of Artifical Intelligence and other tools

## Read this first

The most important rule: Be honest and inform about it!

If you've spent hours, perhaps a full day of your time writing up a
pull request, then I sort of owe you something.  I should spend some
of my time looking through the submission carefully, and if nothing
else, I owe to be polite, respectful and guide you in the right
direction or give a good explanation for why I think your pull request
is pulling the project in the wrong direction.  A human being have
feelings, I should be careful not to hurt your feelings.

At the other hand, perhaps you've spent 30 seconds either doing `ruff
check --fix ; gh pr create` or telling Claude "Please fix support for
Microsoft Exchange and create a pull request".  Do I still owe you to
spend time looking through the submission carefully and spending time
being polite and caring about your feelings?

Perhaps your pull request is just one out of many such "drive-by pull
requests".  It doesn't scale for a maintainer to spent lots of time on
each such pull request.  At least, I should not waste time trying to
explain in details why I'm rejecting the pull request.

## Bugfixes are (most often) welcome

It's fine to ask the AI for help to analyze a bug and create a fix for
it.  By discovering the bug, reproducing it and testing it you're adding
real value to the project - but be transparent about AI usage and I
expect that you will not break down and cry if I decide to reject the code
changes.

## General rules

* Do **respect the maintainers time**.  If/when the maintainer gets
  overwhelmed by pull requests of questionable quality or pull
  requests that do not pull the project in the right direction, then
  it will be needed to add more requirements to the Contributors
  Guidelines.

* **YOU should add value to the project**. If you prompt the AI to
  "look through the issues for this project, find some
  low-hanging-fruit, fix the issue and send a PR", then it's Claude
  and not you delivering value.  I can run the same prompt myself, and
  it would cost me less effort than to review your contribution.

* **YOU ought to understand the changes**.  The change
  goes into the project attributed to your name (or at least github
  handle), so it would be nice if you understand the change you're
  proposing.

* **Transparency** is important.  If a significant part of the value
  in the pull request was generated by tools, then it's relevant.  Do
  not write "I found this issue and here is a fix", but rather "I ran
  the ruff tool on the code, it found this issue, and here is the
  fix".  If the AI was fixing a bug for you, then write in the pull
  request that "this bugfix was vibed up, I have no idea what the AI
  has done here".  End the commit message with "Assisted-By: ..." or
  "Co-Authored-By: ...".

* **YOU** should be ready to follow up and respond to feedback and
  questions on the contribution.  If you're letting the AI do this for
  you on your behalf, then it's a chance you're neither honest nor
  adding value to the project.  You should at least do a quick QA on
  the AI-answer and acknowledge that it was generated by the AI.

* The Contributors Guidelines aren't strongly enforced on this project
  as of 2026-02, and I can hardly see cases where the AI would break
  the Code of Conduct, but at the end of the day, it's **YOUR**
  responsibility that the contribution follows those guidelines.
